@@ -1,18 +1,15 @@
 # encoding: utf-8
 
 module Cri
-
   # Cri::Command represents a command that can be executed on the commandline.
   # It is also used for the commandline tool itself.
   class Command
-
     # Delegate used for partitioning the list of arguments and options. This
     # delegate will stop the parser as soon as the first argument, i.e. the
     # command, is found.
     #
     # @api private
     class OptionParserPartitioningDelegate
-
       # Returns the last parsed argument, which, in this case, will be the
       # first argument, which will be either nil or the command name.
       #
@@ -28,7 +25,7 @@ module Cri
       # @param [Cri::OptionParser] option_parser The option parser
       #
       # @return [void]
-      def option_added(key, value, option_parser)
+      def option_added(_key, _value, _option_parser)
       end
 
       # Called when an argument is parsed.
@@ -42,7 +39,6 @@ module Cri
         @last_argument = argument
         option_parser.stop
       end
-
     end
 
     # @return [Cri::Command, nil] This command’s supercommand, or nil if the
@@ -95,12 +91,12 @@ module Cri
     # @param [String, nil] filename The filename corresponding to the string parameter (only useful if a string is given)
     #
     # @return [Cri::Command] The newly defined command
-    def self.define(string=nil, filename=nil, &block)
+    def self.define(string = nil, filename = nil, &block)
       dsl = Cri::CommandDSL.new
       if string
-        args = filename ? [ string, filename ] : [ string ]
+        args = filename ? [string, filename] : [string]
         dsl.instance_eval(*args)
-      elsif [ -1, 0 ].include? block.arity
+      elsif [-1, 0].include? block.arity
         dsl.instance_eval(&block)
       else
         block.call(dsl)
@@ -115,7 +111,7 @@ module Cri
     # @return [Cri::Command] A basic root command
     def self.new_basic_root
       filename = File.dirname(__FILE__) + '/commands/basic_root.rb'
-      self.define(File.read(filename))
+      define(File.read(filename))
     end
 
     # Returns a new command that implements showing help.
@@ -123,7 +119,7 @@ module Cri
     # @return [Cri::Command] A basic help command
     def self.new_basic_help
       filename = File.dirname(__FILE__) + '/commands/basic_help.rb'
-      self.define(File.read(filename))
+      define(File.read(filename))
     end
 
     def initialize
@@ -141,7 +137,7 @@ module Cri
     # @return [Cri::Command] The command itself
     def modify(&block)
       dsl = Cri::CommandDSL.new(self)
-      if [ -1, 0 ].include? block.arity
+      if [-1, 0].include? block.arity
         dsl.instance_eval(&block)
       else
         block.call(dsl)
@@ -174,11 +170,11 @@ module Cri
     #   should be set (yet)
     #
     # @return [Cri::Command] The subcommand
-    def define_command(name=nil, &block)
+    def define_command(name = nil, &block)
       # Execute DSL
       dsl = Cri::CommandDSL.new
       dsl.name name unless name.nil?
-      if [ -1, 0 ].include? block.arity
+      if [-1, 0].include? block.arity
         dsl.instance_eval(&block)
       else
         block.call(dsl)
@@ -186,7 +182,7 @@ module Cri
 
       # Create command
       cmd = dsl.command
-      self.add_command(cmd)
+      add_command(cmd)
       cmd
     end
 
@@ -200,7 +196,7 @@ module Cri
       # Find by exact name or alias
       @commands.each do |cmd|
         found = cmd.name == name || cmd.aliases.include?(name)
-        return [ cmd ] if found
+        return [cmd] if found
       end
 
       # Find by approximation
@@ -242,23 +238,23 @@ module Cri
     #   supercommand
     #
     # @return [void]
-    def run(opts_and_args, parent_opts={})
+    def run(opts_and_args, parent_opts = {})
       # Parse up to command name
       stuff = partition(opts_and_args)
       opts_before_subcmd, subcmd_name, opts_and_args_after_subcmd = *stuff
 
-      if subcommands.empty? || (subcmd_name.nil? && !self.block.nil?)
+      if subcommands.empty? || (subcmd_name.nil? && !block.nil?)
         run_this(opts_and_args, parent_opts)
       else
         # Handle options
-        self.handle_options(opts_before_subcmd)
+        handle_options(opts_before_subcmd)
 
         # Get command
         if subcmd_name.nil?
           $stderr.puts "#{name}: no command given"
           exit 1
         end
-        subcommand = self.command_named(subcmd_name)
+        subcommand = command_named(subcmd_name)
 
         # Run
         subcommand.run(opts_and_args_after_subcmd, opts_before_subcmd)
@@ -278,122 +274,49 @@ module Cri
     #   block
     #
     # @return [void]
-    def run_this(opts_and_args, parent_opts={})
+    def run_this(opts_and_args, parent_opts = {})
       # Parse
       parser = Cri::OptionParser.new(
-        opts_and_args, self.global_option_definitions)
-      self.handle_parser_errors_while { parser.run }
+        opts_and_args, global_option_definitions)
+      handle_parser_errors_while { parser.run }
       local_opts  = parser.options
       global_opts = parent_opts.merge(parser.options)
       args = parser.arguments
 
       # Handle options
-      self.handle_options(local_opts)
+      handle_options(local_opts)
 
       # Execute
-      if self.block.nil?
-        raise NotImplementedError,
-          "No implementation available for '#{self.name}'"
+      if block.nil?
+        fail NotImplementedError,
+             "No implementation available for '#{name}'"
       end
-      self.block.call(global_opts, args, self)
+      block.call(global_opts, args, self)
     end
 
     # @return [String] The help text for this command
-    def help(params={})
-      is_verbose = params.fetch(:verbose, false)
-
-      text = ''
-
-      # Append name and summary
-      if summary
-        text << "name".formatted_as_title << "\n"
-        text << "    #{name.formatted_as_command} - #{summary}" << "\n"
-        unless aliases.empty?
-          text << "    aliases: " << aliases.map { |a| a.formatted_as_command }.join(' ') << "\n"
-        end
-      end
-
-      # Append usage
-      if usage
-        path = [ self.supercommand ]
-        path.unshift(path[0].supercommand) until path[0].nil?
-        formatted_usage = usage.gsub(/^([^\s]+)/) { |m| m.formatted_as_command }
-        full_usage = path[1..-1].map { |c| c.name.formatted_as_command + ' ' }.join + formatted_usage
-
-        text << "\n"
-        text << "usage".formatted_as_title << "\n"
-        text << full_usage.wrap_and_indent(78, 4) << "\n"
-      end
-
-      # Append long description
-      if description
-        text << "\n"
-        text << "description".formatted_as_title << "\n"
-        text << description.wrap_and_indent(78, 4) + "\n"
-      end
-
-      # Append subcommands
-      unless self.subcommands.empty?
-        text << "\n"
-        text << (self.supercommand ? 'subcommands' : 'commands').formatted_as_title
-        text << "\n"
-
-        shown_subcommands = self.subcommands.select { |c| !c.hidden? || is_verbose }
-        length = shown_subcommands.map { |c| c.name.formatted_as_command.size }.max
-
-        # Command
-        shown_subcommands.sort_by { |cmd| cmd.name }.each do |cmd|
-          text << sprintf("    %-#{length+4}s %s\n",
-            cmd.name.formatted_as_command,
-            cmd.summary)
-        end
-
-        # Hidden notice
-        if !is_verbose
-          diff = self.subcommands.size - shown_subcommands.size
-          case diff
-          when 0
-          when 1
-            text << "    (1 hidden command omitted; show it with --verbose)\n"
-          else
-            text << "    (#{diff} hidden commands omitted; show them with --verbose)\n"
-          end
-        end
-      end
-
-      # Append options
-      groups = { 'options' => self.option_definitions }
-      if self.supercommand
-        groups["options for #{self.supercommand.name}"] = self.supercommand.global_option_definitions
-      end
-      length = groups.values.inject(&:+).map { |o| o[:long].to_s.size }.max
-      groups.keys.sort.each do |name|
-        defs = groups[name]
-        unless defs.empty?
-          text << "\n"
-          text << "#{name}".formatted_as_title
-          text << "\n"
-          ordered_defs = defs.sort_by { |x| x[:short] || x[:long] }
-          ordered_defs.each do |opt_def|
-            text << sprintf(
-              "    %-2s %-#{length+6}s",
-              opt_def[:short] ? ('-' + opt_def[:short]) : '',
-              opt_def[:long] ? ('--' + opt_def[:long]) : '').formatted_as_option
-
-            text << opt_def[:desc] << "\n"
-          end
-        end
-      end
-
-      text
+    #
+    # @option params [Boolean] :verbose true if the help output should be
+    #   verbose, false otherwise.
+    #
+    # @option params [IO] :io ($stdout) the IO the help text is intended for.
+    #   This influences the decision to enable/disable colored output.
+    def help(params = {})
+      HelpRenderer.new(self, params).render
     end
 
     # Compares this command's name to the other given command's name.
+    #
+    # @param [Cri::Command] other The command to compare with
+    #
+    # @return [-1, 0, 1] The result of the comparison between names
+    #
+    # @see Object<=>
     def <=>(other)
-      self.name <=> other.name
+      name <=> other.name
     end
 
-  protected
+    private
 
     def handle_options(opts)
       opts.each_pair do |key, value|
@@ -408,29 +331,24 @@ module Cri
       delegate = Cri::Command::OptionParserPartitioningDelegate.new
       parser = Cri::OptionParser.new(opts_and_args, global_option_definitions)
       parser.delegate = delegate
-      self.handle_parser_errors_while { parser.run }
-      parser
+      handle_parser_errors_while { parser.run }
 
       # Extract
       [
         parser.options,
         delegate.last_argument,
-        parser.unprocessed_arguments_and_options
+        parser.unprocessed_arguments_and_options,
       ]
     end
 
     def handle_parser_errors_while(&block)
-      begin
-        block.call
-      rescue Cri::OptionParser::IllegalOptionError => e
-        $stderr.puts "#{name}: illegal option -- #{e}"
-        exit 1
-      rescue Cri::OptionParser::OptionRequiresAnArgumentError => e
-        $stderr.puts "#{name}: option requires an argument -- #{e}"
-        exit 1
-      end
+      block.call
+    rescue Cri::OptionParser::IllegalOptionError => e
+      $stderr.puts "#{name}: illegal option -- #{e}"
+      exit 1
+    rescue Cri::OptionParser::OptionRequiresAnArgumentError => e
+      $stderr.puts "#{name}: option requires an argument -- #{e}"
+      exit 1
     end
-
   end
-
 end
