@@ -1,10 +1,11 @@
 # encoding: utf-8
 
 module Cri
-
   # The command DSL is a class that is used for building and modifying
   # commands.
   class CommandDSL
+    # @return [Cri::Command] The built command
+    attr_reader :command
 
     # Creates a new DSL, intended to be used for building a single command. A
     # {CommandDSL} instance is not reusable; create a new instance if you want
@@ -12,15 +13,10 @@ module Cri
     #
     # @param [Cri::Command, nil] command The command to modify, or nil if a
     #   new command should be created
-    def initialize(command=nil)
+    def initialize(command = nil)
       @command = command || Cri::Command.new
     end
 
-    # @return [Cri::Command] The built command
-    def command
-      @command
-    end
-
     # Adds a subcommand to the current command. The command can either be
     # given explicitly, or a block can be given that defines the command.
     #
@@ -29,7 +25,7 @@ module Cri
     #   added as a subcommand
     #
     # @return [void]
-    def subcommand(command=nil, &block)
+    def subcommand(command = nil, &block)
       if command.nil?
         command = Cri::Command.define(&block)
       end
@@ -108,13 +104,17 @@ module Cri
     # @option params [Boolean] :multiple Whether or not the option should
     #   be multi-valued
     #
+    # @option params [Boolean] :hidden Whether or not the option should
+    #   be printed in the help output
+    #
     # @return [void]
-    def option(short, long, desc, params={}, &block)
+    def option(short, long, desc, params = {}, &block)
       requiredness = params.fetch(:argument, :forbidden)
       multiple = params.fetch(:multiple, false)
+      hidden = params.fetch(:hidden, false)
 
       if short.nil? && long.nil?
-        raise ArgumentError, "short and long options cannot both be nil"
+        fail ArgumentError, 'short and long options cannot both be nil'
       end
 
       @command.option_definitions << {
@@ -124,6 +124,7 @@ module Cri
         :argument => requiredness,
         :multiple => multiple,
         :block    => block,
+        :hidden   => hidden,
       }
     end
     alias_method :opt, :option
@@ -140,12 +141,15 @@ module Cri
     # @option params [Boolean] :multiple Whether or not the option should
     #   be multi-valued
     #
+    # @option params [Boolean] :hidden Whether or not the option should
+    #   be printed in the help output
+    #
     # @return [void]
     #
     # @see {#option}
-    def required(short, long, desc, params={}, &block)
+    def required(short, long, desc, params = {}, &block)
       params = params.merge(:argument => :required)
-      self.option(short, long, desc, params, &block)
+      option(short, long, desc, params, &block)
     end
 
     # Adds a new option with a forbidden argument to the command. If a block
@@ -160,12 +164,15 @@ module Cri
     # @option params [Boolean] :multiple Whether or not the option should
     #   be multi-valued
     #
+    # @option params [Boolean] :hidden Whether or not the option should
+    #   be printed in the help output
+    #
     # @return [void]
     #
     # @see {#option}
-    def flag(short, long, desc, params={}, &block)
+    def flag(short, long, desc, params = {}, &block)
       params = params.merge(:argument => :forbidden)
-      self.option(short, long, desc, params, &block)
+      option(short, long, desc, params, &block)
     end
     alias_method :forbidden, :flag
 
@@ -181,12 +188,15 @@ module Cri
     # @option params [Boolean] :multiple Whether or not the option should
     #   be multi-valued
     #
+    # @option params [Boolean] :hidden Whether or not the option should
+    #   be printed in the help output
+    #
     # @return [void]
     #
     # @see {#option}
-    def optional(short, long, desc, params={}, &block)
+    def optional(short, long, desc, params = {}, &block)
       params = params.merge(:argument => :optional)
-      self.option(short, long, desc, params, &block)
+      option(short, long, desc, params, &block)
     end
 
     # Sets the run block to the given block. The given block should have two
@@ -203,8 +213,8 @@ module Cri
     # @return [void]
     def run(&block)
       unless [2, 3].include?(block.arity)
-        raise ArgumentError,
-          "The block given to Cri::Command#run expects two or three args"
+        fail ArgumentError,
+             'The block given to Cri::Command#run expects two or three args'
       end
 
       @command.block = block
