@@ -1,6 +1,6 @@
 # encoding: utf-8
 
-flag :h, :help, 'show help for this command' do |value, cmd|
+flag :h, :help, 'show help for this command' do |_value, cmd|
   puts cmd.help
   exit 0
 end
